sharlatan pushed a commit to branch python-team
in repository guix.
commit 0bf06b6a0a071dd10ef98f4de4e31697a4f7115f
Author: Sharlatan Hellseher <[email protected]>
AuthorDate: Wed Mar 26 21:58:22 2025 +0000
gnu: python-peaks2utr: Update to 1.4.1 and fix build.
* gnu/packages/bioinformatics.scm (python-peaks2utr): Update to 1.4.1.
[arguments] <test-flags>: Skip 2 more similar failing test.
<phases>: Add 'relax-requirements.
Change-Id: Ia26903116915c4ef031b4a6bdb5dae64d109a1f4
---
gnu/packages/bioinformatics.scm | 18 ++++++++++++++----
1 file changed, 14 insertions(+), 4 deletions(-)
diff --git a/gnu/packages/bioinformatics.scm b/gnu/packages/bioinformatics.scm
index b7b70b0233..7ce522c8df 100644
--- a/gnu/packages/bioinformatics.scm
+++ b/gnu/packages/bioinformatics.scm
@@ -3288,19 +3288,29 @@ encountered in PDB files prior to simulation tasks.")
(define-public python-peaks2utr
(package
(name "python-peaks2utr")
- (version "1.2.0")
+ (version "1.4.1")
(source (origin
(method url-fetch)
(uri (pypi-uri "peaks2utr" version))
(sha256
(base32
- "1idp9cgwqxvryf4qqrc1xjsamfqn3jmr56kmjp2h1ysmckwmhw4v"))))
+ "104il0kk61q07b58g9xrss7xflwlbx4kzsmw9iih99lhfsii0wzg"))))
(build-system pyproject-build-system)
(arguments
(list
#:test-flags
- ;; These two tests fail because file names are not URLs.
- '(list "-k" "not test_annotation.py")))
+ ;; These tests fail because file names are not URLs.
+ '(list "-k" (string-join
+ (list "not test_forward_strand_annotations"
+ "test_matching_chr"
+ "test_reverse_strand_annotations")
+ " and not "))
+ #:phases
+ '(modify-phases %standard-phases
+ (add-after 'unpack 'relax-requirements
+ (lambda _
+ (substitute* "setup.cfg"
+ (("==") ">=")))))))
(propagated-inputs
(list python-asgiref
python-gffutils